@@ -3,8 +3,6 @@
 # This software is released under the MIT License.
 # http://opensource.org/licenses/mit-license.php
 import os
-import subprocess
-import sys
 from itertools import chain
 
 from make_runner import command_line, makefile_parser, utils
@@ -34,7 +32,10 @@ def main():
     for option in ["makefile", "jobs", "load_average"]:
         if getattr(args, option, None) is not None:
             runner.append(utils.normalize_option_name(option))
-            runner.append(args.option)
+            if option == "makefile":
+                runner.append(makefile_path)
+            else:
+                runner.append(getattr(args, option))
 
     runner += args.tasks
     for option in options:
@@ -42,10 +43,15 @@ def main():
         option_value = getattr(
             args, utils.normalize_option_name(option_name, argument=False), None
         )
+        if option["flag"] is not None:
+            if option_value:
+                runner.append("{}=1".format(option_name))
+            continue
         if option_value is not None:
             runner.append("{}={}".format(option_name, option_value))
+            continue
 
-    subprocess.run(runner)
+    os.execvp(runner[0], runner)
 
 
 if __name__ == "__main__":
